////////////////////////////
/// common
////////////////////////////
function validateContent(failed, failedMessage) {
    if (failed == 1) {
        failedMessage += ''
        if (failedMessage.length > 0) {
            JSExecutor.alertMsg(failedMessage)
        }
        return false
    }

    return true
}

////////////////////////////
/// mainpage
////////////////////////////

var OperationTypeEnum = Object.freeze({ SAVE: 1, PUBLISH: 2 })

function adjustAddPrivilegeButtonVisible() {
    var shopEntityIds = currentShops().map(function (t) {
        return t.shopEntityId
    })

    JSExecutor.setProp('s_2_3', 'hide', shopEntityIds.length == 0)
}
function submitModification(opType) {
    JSExecutor.log(arguments.callee.name)

    JSExecutor.getFormDataCallBack(function (failed, failedMessage, data) {
        JSExecutor.log(data)

        if (!validateContent(failed, failedMessage) || !validateValidityDate()) { return false }


        //mall日常项目中, 隐藏使用范围, 并默认为外卖堂食皆可用
        if (!data.applyScope) {
            data.applyScope = 3;
        }

        var extendInfo = JSExecutor.getExtendInfo()
        var activityId = extendInfo.activityId
        var activityType = extendInfo.activityType
        var plateEntityId = extendInfo.plateEntityId
        var params = {
            'activity_id': activityId,
            'activity_data': data,
            'option_type': opType,
            'plate_entity_id': plateEntityId,
            'activity_type': activityType
        }
        JSExecutor.submit('/plat/v1/modify_activity', params, 1);
    })
}

function validateValidityDate() {
    JSExecutor.log(arguments.callee.name)

    var startDate = JSExecutor.getVal('s_3_0')
    var endDate = JSExecutor.getVal('s_3_1')

    if (startDate > 0 && JSExecutor.compoareToday(startDate) < 0) {
        JSExecutor.alertMsg('开始时间不得早于今天')
        return false
    }
    if (startDate > 0 && endDate > 0 && JSExecutor.dayCompare(endDate, startDate) < 0) {
        JSExecutor.alertMsg('结束时间不得早于开始时间')
        return false
    }
    return true
}

function isExistActivity() {
    JSExecutor.log(arguments.callee.name)

    var extendInfo = JSExecutor.getExtendInfo()
    return extendInfo.activityId != null
}

function onload() {
    JSExecutor.log(arguments.callee.name)

    var extendInfo = JSExecutor.getExtendInfo()

    JSExecutor.log(extendInfo)

    var isPreviewState = extendInfo.isPreviewState
    var remoteInfo = extendInfo.remoteInfo
    if (remoteInfo != null) {
        var permission = remoteInfo.permission
        var activityState = remoteInfo.activityState

        JSExecutor.setProp('s_3_3', 'hide', isPreviewState == 1)
        JSExecutor.setProp('s_3_4', 'hide', !(permission == 1 && activityState == 1))
        JSExecutor.setProp('s_3_4', 'disable', !(permission == 1 && activityState == 1))
    }
    // var isChain = extendInfo.isChain
    // JSExecutor.setProp('s_0_5', 'hide', isChain == 0)
}

//适用对象
function onloadofSuitPeople(){
    var extendInfo = JSExecutor.getExtendInfo()
   if (extendInfo.entityType == 4) {
       if(JSExecutor.getVal('suitPeople') == 2){
           JSExecutor.setProp('suitPeople','disable',1);
           JSExecutor.setProp('suitPeople','remark',"");
       }else{
           JSExecutor.setProp('suitPeople','disable',0);
           JSExecutor.setProp('suitPeople','remark',"选择不限时，即所有人都可参加此活动；选择全部会员时，即拥有特权卡（原会员卡）、新会员体系卡、会员等级特权卡的顾客可参与此活动；");
       }
   }
}

// 头部活动相关的提示
function onloadOfGuide() {
    var extendInfo = JSExecutor.getExtendInfo()
    var tGuideContent = extendInfo['initialDataInfo']['guide'];
    if (tGuideContent != undefined) {
        JSExecutor.setProp('guide', 'hide', 0)
        JSExecutor.setVal('guide', tGuideContent);
    }
}

function publish() {
    JSExecutor.log(arguments.callee.name)

    submitModification(OperationTypeEnum.PUBLISH)
}

function save() {
    JSExecutor.log(arguments.callee.name)

    if (isExistActivity() && !JSExecutor.hasDataUnsave()) {
        JSExecutor.alertMsg('未有任何改动，请点击返回')
        return
    }

    submitModification(OperationTypeEnum.SAVE)
}

function stop() {
    JSExecutor.log(arguments.callee.name)

    var extendInfo = JSExecutor.getExtendInfo()
    var activityId = extendInfo.activityId
    var params = { 'activity_id': activityId }
    JSExecutor.submit('/plat/v1/stop_activity', params, 1);
}

function deleteTriggerTimePrivilege(itemIndex) {
    JSExecutor.log(arguments.callee.name)

    var privileges = JSExecutor.getVal('s_2_3')

    JSExecutor.log(privileges)
    privileges.splice(itemIndex, 1)

    JSExecutor.setVal('s_2_3', privileges)
}

function modifyTriggerTimePrivilege(aPreferentialWay, itemIndex) {
    JSExecutor.log(arguments.callee.name)

    // 兼容安卓返回的数组添加元素崩溃问题
    var privileges = JSExecutor.getVal('s_2_3')

    if (itemIndex < 0) {
        privileges.push(aPreferentialWay)
    } else {
        privileges[itemIndex] = aPreferentialWay
    }

    privileges.sort(function (t, n) {
        return t.triggerTime - n.triggerTime
    })

    JSExecutor.setVal('s_2_3', privileges)
}

function applyShopsChanged() {
    JSExecutor.log(arguments.callee.name)

    // 清空选择的优惠券
    var preferentialWays = JSExecutor.getVal('s_2_3')
    if (preferentialWays != null && preferentialWays.length > 0) {
        preferentialWays.forEach(function (t) {
            if (t.coupons != null) {
                t.coupons.length = 0
            }
        })
        JSExecutor.setVal('s_2_3', preferentialWays)
    }

    adjustAddPrivilegeButtonVisible()
}

function applyShopsLoad() {
    var extendInfo = JSExecutor.getExtendInfo()
    // if (extendInfo.isChain == 1) {
    adjustAddPrivilegeButtonVisible()
    // }
}

function s23OnPackageInputParam() {
    JSExecutor.log(arguments.callee.name)

    var inputParam = {}
    // 把shopEntityIds存入子页面入口组件
    var shops = currentShops()
    if (shops != null) {
        inputParam.shopEntityIds = shops.map(function (t) {
            return t.shopEntityId
        })
    }

    // 过滤相同的触发次数
    inputParam.triggerTimes = JSExecutor.getVal('s_2_3').map(function (t) {
        return t.triggerTime.toString()
    })

    return inputParam
}
////////////////////////////
/// subpage
////////////////////////////

function subpageTriggerTimePrivilegeOnload() {
    JSExecutor.log(arguments.callee.name)

    var extendInfo = JSExecutor.getExtendInfo()

    JSExecutor.log(extendInfo)

    // 只能往大了加
    JSExecutor.setProp('s_2_3_3', 'hide', extendInfo.isPreviewState == 1 || extendInfo.itemIndex < 0)
    // 把传入的shopEntityIds传入添加优惠券组件
    JSExecutor.setProp('s_2_3_2', 'inputParam', extendInfo.localInfo.shopEntityIds)
}

// 获取当前的适用门店
function currentShops() {
    var suitShopsKey = 'suitShops';
    if (JSExecutor.getExtendInfo().entityType == 4) {
        suitShopsKey = 'mallSuitShops';
    }
    return JSExecutor.getVal(suitShopsKey);
}

//调用方为subpage, 目的是在上一个js上下文中获取上一个页面适用门店当前设置
function getShopsFromLastPage() {
    return JSExecutor.execParentContextFuncWithParams('currentShops', [])
}

function subpageSaveTriggerTimePrivilege() {
    JSExecutor.log(arguments.callee.name)

    JSExecutor.getFormDataCallBack(function (isFailed, verifyFailedTip, formData) {
        JSExecutor.log(formData)

        if (!validateContent(isFailed, verifyFailedTip)) { return false }

        var extendInfo = JSExecutor.getExtendInfo()
        var triggerTimes = extendInfo.localInfo.triggerTimes
        var triggerTime = JSExecutor.getVal('s_2_3_0')

        JSExecutor.log("triggerTime: " + triggerTime)
        JSExecutor.log("triggerTimes: " + triggerTimes)
        JSExecutor.log("itemIndex: " + extendInfo.itemIndex)

        if (triggerTimes) {
            var index = triggerTimes.findIndex(function (t) {
                return t == triggerTime
            })
            if (index != extendInfo.itemIndex && index != -1) {
                JSExecutor.alertMsg("在店消费总次数【" + triggerTime + "次】已存在！")
                return false
            }
        }

        JSExecutor.execParentContextFuncWithParams('modifyTriggerTimePrivilege', [formData, extendInfo.itemIndex])
        JSExecutor.back()

        return true
    })
}


function subpageDeleteTriggerTimePrivilege() {
    JSExecutor.log(arguments.callee.name)

    var extendInfo = JSExecutor.getExtendInfo()
    JSExecutor.execParentContextFuncWithParams('deleteTriggerTimePrivilege', [extendInfo.itemIndex])
    JSExecutor.back()
}

function onChangeOfParkingCouponSwitch() {
    var tParkingCouponSwitch = JSExecutor.getVal('parkCouponSwitch');
    if (tParkingCouponSwitch) {
        JSExecutor.setProp('parkCoupons', 'hide', 0)
    }
    else {
        JSExecutor.setProp('parkCoupons', 'hide', 1)
    }
}

/** 适用范围 */
function onChangeOfApplyScope() {
    var value = JSExecutor.getVal('s_0_4');
    switch (parseInt(value)) {
        case 1:
            JSExecutor.setProp('s_0_4', 'remark', '');
            break;
        case 2:
            JSExecutor.setProp('s_0_4', 'remark', '外卖场景暂不支持赠送优惠券。');
            break;
        case 3:
            JSExecutor.setProp('s_0_4', 'remark', '外卖场景暂不支持赠送优惠券。');
            break;
        default:
            JSExecutor.setProp('s_0_4', 'remark', '');
            break;
    }
}